@@ -5,11 +5,14 @@ from scipy.linalg import eigvalsh
 
 def phi(gr, nodes, other=None):
     if gr.directed():
-        ind_i = np.arange(gr.size())[[node in nodes for node in gr.get_ids()]]
+        ind_i = np.arange(gr.size())[
+            np.array([node in nodes for node in gr.get_ids()])]
         if other is not None:
-            ind_j = np.arange(gr.size())[[node in other for node in gr.get_ids()]]
+            ind_j = np.arange(gr.size())[
+                np.array([node in other for node in gr.get_ids()])]
         else:
-            ind_j = np.arange(gr.size())[[node not in nodes for node in gr.get_ids()]]
+            ind_j = np.arange(gr.size())[
+                np.array([node not in nodes for node in gr.get_ids()])]
         pi = gr.get_stat_dist()
         c = np.sum(pi[ind_i])
         v = np.sum(pi[ind_j])
