@@ -59,6 +59,16 @@ class SGraph:
         sub = self.gr.subgraph(nodes).copy()
         return SGraph(sub)
 
+    def subgraph_from(self, node, nm):
+        nodes = [node]
+        while len(nodes) < nm:
+            nodes = np.append(nodes,
+                              np.random.choice(
+                                  np.append(self.get_in_degrees(nodes), self.get_out_degrees(nodes))))
+            nodes = np.unique(nodes)
+
+        return self.subgraph(nodes)
+
     def get_ids(self, stable=False):
         if stable:
             return np.array(list(self.gr.nodes()))
@@ -138,7 +148,7 @@ class SGraph:
     def get_prob_matrix(self):
         if self.p is None:
             p = nx.to_numpy_matrix(self.gr)
-            self.p = np.divide(p, np.sum(p, axis=0))
+            self.p = np.nan_to_num(np.divide(p, np.sum(p, axis=0)))
         return self.p
 
     def get_stat_dist(self):
@@ -213,11 +223,12 @@ class SGraph:
         return self.gr.number_of_edges()
 
     def get_in_degrees(self, ind, w=None, un=False, bsc=0):
+        ind_l = np.append([], ind)
         if self.directed():
-            res = [x[0] for x in self.gr.in_edges(ind)]
+            res = [x[0] for ind_ in ind_l for x in self.gr.in_edges(ind_)]
         else:
-            res = [x[0] for x in self.gr.edges(ind) if x[0] != ind] + [
-                x[1] for x in self.gr.edges(ind) if x[1] != ind
+            res = [x[0] for ind_ in ind_l for x in self.gr.edges(ind_) if x[0] != ind_] + [
+                x[1] for ind_ in ind_l for x in self.gr.edges(ind_) if x[1] != ind_
             ]
 
         if un:
@@ -228,11 +239,13 @@ class SGraph:
             return np.array([self.get_edge_data(res, ind, w, bsc=bsc)])
 
     def get_out_degrees(self, out, w=None, un=True, bsc=0):
+        out_l = np.append([], out)
+
         if self.directed():
-            res = [x[1] for x in self.gr.out_edges(out)]
+            res = [x[1] for out_ in out_l for x in self.gr.out_edges(out_)]
         else:
-            res = [x[0] for x in self.gr.edges(out) if x[0] != out] + [
-                x[1] for x in self.gr.edges(out) if x[1] != out
+            res = [x[0] for out_ in out_l for x in self.gr.edges(out_) if x[0] != out_] + [
+                x[1] for out_ in out_l for x in self.gr.edges(out_) if x[1] != out_
             ]
 
         if un:
@@ -357,14 +370,14 @@ class SGraph:
         lv = np.unique(lv, return_counts=count)
         return np.array(xs), lv
 
-    def get_all_short_pathes(self, nodes, plain=True):
+    def get_all_short_pathes(self, nodes, others=None, plain=True, un=True):
         if len(nodes) < 2:
             return [], []
 
         pathes, ln = [], []
 
         for node in nodes:
-            pathes_, ln_ = self.get_short_paths(node, nodes)
+            pathes_, ln_ = self.get_short_paths(node, nodes, un, others)
             pathes += pathes_
             if plain:
                 ln += ln_
@@ -395,60 +408,91 @@ class SGraph:
                 ln.append(len(path) - 1)
         return pathes, ln
 
-    def get_short_paths(self, root, nodes):
+    def get_short_paths(self, root, nodes, un, others):
         if len(nodes) < 2:
             return [], []
 
-        pathes, ln = [], []
-        done = [root]
-        step = [[root]]
-
-        while len(step) != 0:
-            if len(pathes) == len(nodes) - 1:
-                break
-
-            step_ = []
-            for st in step:
-                for res in self.get_in_degrees(st[-1]):
-                    if res not in done:
-                        done.append(res)
-                        st_ = st.copy()
-                        st_.append(res)
-
-                        if res in nodes:
-                            pathes.append(st_)
-                            ln.append(len(st_) - 1)
-                        else:
-                            step_.append(st_)
-            step = step_
-        return pathes, ln
-
-    def get_short_paths2(self, root, nodes):
-        if len(nodes) < 2:
-            return [], []
+        if others is None:
+            others = []
 
         pathes, ln = [], []
-        done = [root]
-        step = [[root]]
 
-        while len(step) != 0:
-            if len(pathes) == len(nodes) - 1:
-                break
+        if un:
+            step = [[root]]
+            done = []
+            ends, end_l = [], []
+            while len(step) != 0:
+                if len(pathes) == len(nodes) - 1:
+                    break
 
-            step_ = []
-            for st in step:
-                for res in self.get_in_degrees(st[-1]):
-                    if res not in done:
-                        done.append(res)
-                        st_ = st.copy()
-                        st_.append(res)
+                step_ = []
+                for st in step:
+                    for res in self.get_in_degrees(st[-1]):
+                        if res in others:
+                            continue
+
+                        if res not in done:
+                            done.append(res)
+                            st_ = st.copy()
+                            st_.append(res)
+
+                            if res in nodes:
+                                if res in ends:
+                                    if end_l[res.index(ends)] == len(st_) - 1:
+                                        pathes.append(st_)
+                                        ln.append(len(st_) - 1)
+                                else:
+                                    ends.append(res)
+                                    pathes.append(st_)
+                                    ln.append(len(st_) - 1)
+                            else:
+                                step_.append(st_)
+                step = step_
+        else:
+            step = [[root]]
+            while len(step) != 0:
+                if len(pathes) == len(nodes) - 1:
+                    break
+
+                step_ = []
+                for st in step:
+                    for res in self.get_in_degrees(st[-1]):
+                        if res in others:
+                            continue
+
+                        if res not in st[1:]:
+                            st_ = st.copy()
+                            st_.append(res)
+
+                            if res in nodes:
+                                pathes.append(st_)
+                                ln.append(len(st_) - 1)
+                            else:
+                                step_.append(st_)
+                step = step_
+            #done = np.array([root])
+            #nxt = np.unique(self.get_in_degrees(done))
+            #nxt = nxt[~np.isin(nxt, done) & ~np.isin(nxt, others)]
+
+            #while nxt.size > 0:
+            #    done = np.append(done, nxt[np.isin(nxt, nodes)])
+            #    nxt = np.unique(self.get_in_degrees(done[~np.isin(done, nodes) & ~np.isin(done, others)]))
+            #    nxt = nxt[~np.isin(nxt, done) & ~np.isin(nxt, others)]
+
+            #nds = [nd for nd in done if nd != root]
+            #sb = self.gr.subgraph(done)
+            #for pth in nx.all_simple_paths(sb, source=root, target=nds):
+            #    if np.sum(np.isin(pth, nodes)) == 2:
+            #        pathes.append(pth)
+            #        ln.append(len(pth)-1)
+
+            #try:
+            #    for pth in nx.find_cycle(sb, source=root, orientation="original"):
+            #        if np.sum(np.isin(pth, nodes)) == 1:
+            #            pathes.append(pth)
+            #            ln.append(len(pth))
+            #except:
 
-                        if res in nodes:
-                            pathes.append(st_)
-                            ln.append(len(st_) - 1)
-                        else:
-                            step_.append(st_)
-            step = step_
         return pathes, ln
 
 
