@@ -113,18 +113,17 @@ class Creator:
         gr = nx.read_edgelist(path, create_using=nx.DiGraph())
         print("loaded")
 
-        if nm is None:
-            res = SGraph(gr)
-        else:
+        res = SGraph(gr)
+        if nm is not None:
             choiced = np.random.choice(gr.nodes())
-            res = Creator.create_subgraph(gr, choiced, nm)
+            res = res.subgraph_from(choiced, nm)
 
         actual(res, sigma)
         print("attrs added")
         return res
 
     @staticmethod
-    def simple_graph(network, pre="../", typ=nx.DiGraph, dl=" ", clean=False):
+    def simple_graph(network, pre="../", typ=nx.DiGraph, dl=" "):
         path = pre + "pge/samples/networks/web-"
         if network == "BS":
             path += "BerkStan.txt"
@@ -136,11 +135,12 @@ class Creator:
             path = network
         res = nx.read_edgelist(path, create_using=typ(), delimiter=dl)
 
-        sub = max(nx.connected_components(res), key=len)
-        res = SGraph(res).subgraph(sub)
+        if typ == nx.DiGraph or typ == nx.MultiGraph:
+            res = SGraph(res)
+        else:
+            sub = max(nx.connected_components(res), key=len)
+            res = SGraph(res).subgraph(sub)
 
-        if clean:
-            res.del_attrs(["pos"])
         return res
 
     @staticmethod
