@@ -1,18 +1,20 @@
 import numpy as np
 
 
-def first_order(graph, basis, typ="in"):
+def first_order(graph, basis, typ="in", inn=None):
     clss = []
     for _ in np.arange(len(basis)+1):
         clss.append([])
 
+    if inn is None:
+        inn = []
+        for bs in basis:
+            inn = inn + list(bs)
+
     for node in graph.get_ids():
         fnd = False
-        for i in np.arange(len(basis)):
-            if node in basis[i]:
-                fnd = True
-                break
-        if fnd:
+
+        if node in inn:
             continue
 
         if typ == "in":
@@ -36,4 +38,20 @@ def first_order(graph, basis, typ="in"):
 
 
 def full_classification(graph, basis, typ="in"):
-    return
+    clss = []
+
+    inn = []
+    while True:
+        for bs in basis:
+            inn = inn + list(bs)
+
+        print(len(inn))
+        res = first_order(graph, basis, typ, inn)
+        if np.sum([len(r) for r in res[:len(res)-1]]) < len(res)-1:
+            clss = clss + [[res[-1]]]
+            break
+        else:
+            print([len(r) for r in res])
+        basis = res[:len(res)-1]
+        clss = clss + [basis]
+    return clss
