@@ -41,3 +41,23 @@ class FixSpreadModel(SpreadingModel):
             res = np.append(res, [time.copy() for time in self.times])
         res = np.reshape(res, (res.size // 3, 3))
         return res
+
+    def one_spread(self, tick):
+        self.rs = self.graph.size()
+
+        n = 1
+        self.init()
+        res = {node: 0 for node in self.graph.get_ids() if len(self.received[node]) == 1}
+
+        while self.rs > np.min([time[1] for time in self.times]):
+            if n > tick:
+                break
+
+            self.iteration()
+            self.update(n)
+            res.update({node: n for node in self.graph.get_ids() if
+                        len(self.received[node]) == 1 and node not in list(res.keys())})
+            n += 1
+
+        res.update({node: tick*100 for node in self.graph.get_ids() if node not in list(res.keys())})
+        return res, n
